==> org.jresearch.commons.gwt.base-1.0.2.jar: org/jresearch/commons/gwt/client/base/resource/ComplexText.java <==
package org.jresearch.commons.gwt.client.base.resource;

import javax.annotation.Nonnull;

import com.google.gwt.i18n.client.Messages;

public interface ComplexText extends Messages {

    @DefaultMessage("Error: {0}")
    String error(Throwable data);

    /** Duration unit */
    @DefaultMessage("year")
    String year();

    /** Duration unit */
    @DefaultMessage("years")
    String years();

    /** Duration unit */
    @DefaultMessage("month")
    String month();

    /** Duration unit */
    @DefaultMessage("months")
    String months();

    /** Duration unit */
    @DefaultMessage("day")
    String day();

    /** Duration unit */
    @DefaultMessage("days")
    String days();

    /** Duration unit */
    @DefaultMessage("hour")
    String hour();

    /** Duration unit */
    @DefaultMessage("hours")
    String hours();

    /** Duration unit */
    @DefaultMessage("minute")
    String minute();

    /** Duration unit */
    @DefaultMessage("minutes")
    String minutes();

    /** Duration unit */
    @DefaultMessage("second")
    String second();

    /** Duration unit */
    @DefaultMessage("seconds")
    String seconds();

    /** Duration unit */
    @DefaultMessage("millisecond")
    String millisecond();

    /** Duration unit */
    @DefaultMessage("milliseconds")
    String milliseconds();

    /** Duration unit */
    @DefaultMessage("undefined")
    String undefined();

    /** Default application module description */
    @Nonnull
    @DefaultMessage("No description")
    String noDescription();

}

==> org.jresearch.commons.gwt.base-1.0.27.jar: org/jresearch/commons/gwt/client/base/resource/ComplexText.java <==
package org.jresearch.commons.gwt.client.base.resource;

import javax.annotation.Nonnull;

import com.google.gwt.i18n.client.Messages;
import com.google.gwt.safehtml.shared.SafeHtml;

public interface ComplexText extends Messages {

    @DefaultMessage("Error: {0}")
    String error(Throwable data);

    /** Duration unit */
    @DefaultMessage("year")
    String year();

    /** Duration unit */
    @DefaultMessage("years")
    String years();

    /** Duration unit */
    @DefaultMessage("month")
    String month();

    /** Duration unit */
    @DefaultMessage("months")
    String months();

    /** Duration unit */
    @DefaultMessage("day")
    String day();

    /** Duration unit */
    @DefaultMessage("days")
    String days();

    /** Duration unit */
    @DefaultMessage("hour")
    String hour();

    /** Duration unit */
    @DefaultMessage("hours")
    String hours();

    /** Duration unit */
    @DefaultMessage("minute")
    String minute();

    /** Duration unit */
    @DefaultMessage("minutes")
    String minutes();

    /** Duration unit */
    @DefaultMessage("second")
    String second();

    /** Duration unit */
    @DefaultMessage("seconds")
    String seconds();

    /** Duration unit */
    @DefaultMessage("millisecond")
    String millisecond();

    /** Duration unit */
    @DefaultMessage("milliseconds")
    String milliseconds();

    /** Duration unit */
    @DefaultMessage("undefined")
    String undefined();

    /** Default application module description */
    @Nonnull
    @DefaultMessage("No description")
    String noDescription();

    /** Information message about offline mode */
    @Nonnull
    @DefaultMessage("Offline mode: {0}")
    SafeHtml offlineMode(boolean isOffline);

}
